/*
 * file: pv_default.c
 * This file is part of the libpv library.
 *
 * Copyright 2005 Pengutronix
 *
 * Please send bug reports to bugs@pengutronix.de
 *
 * See COPYING for the status of this software.
 */

#include <libpv_config.h>

#include <errno.h>
#include <string.h>

#include <pv_default.h>
#include <libpv.h>
#include <pv_bs.h>

/*
 * this functions flushes!
 */
int pv_default(pv_engine_t *engine_anon, void *pv_var)
{
	struct pv_engine	*engine = (struct pv_engine *)engine_anon;
	struct pv		*pv;
	off_t			pv_var_offset = 0;
	int			finished = 0;

	if (pv_var) {
		pv_var_offset = pv_var - engine->store.map;
		if (pv_var_offset < 0 || pv_var_offset >= engine->store.size)
			return -EINVAL;
	}

	for (goto_head(&engine->pv_list); !finished; goto_next(&engine->pv_list)) {
		if (is_last(engine->pv_list))
			finished=1;

		pv = (struct pv *)list_get_element_data(engine->pv_list);
		if (pv_var == NULL
		    || pv->offset == pv_var_offset) {
			pv_default_pv(engine, pv);
			if (pv_var != NULL) {
				pv_bs_flush_pv(engine, pv);
				return 0;
			}
		}
	}

	if (pv_var == NULL) {
		pv_bs_flush_all(engine);
		return 0;
	}

	return -EINVAL;
}

/* end of file pv_default.c */
